Path-LZerD
==========
Path-LZerD: multimeric protein complex assembly order prediction

Path-LZerD uses the output of Multi-LZerD to predict the assembly order of a
multimeric protein complex.

License: GPL v3 for academic use.
(For commercial use, please contact us for alternate licensing)

Contact: Daisuke Kihara (dkihara@purdue.edu)

Dependencies
============

Binary dependencies
-------------------

- LZerD (http://kiharalab.org/proteindocking/lzerd.php)
- Multi-LZerD (http://kiharalab.org/proteindocking/multilzerd.php)
- Zero or more scoring functions:
    - GOAP (also computes DFIRE; http://cssb.biology.gatech.edu/GOAP/index.html)
    - ITScorePro (http://zoulab.dalton.missouri.edu/resources.html)
    - SOAP-PP (https://salilab.org/SOAP/)
    - OPUS-PSP (http://ma-lab.rice.edu/soft.php)

Python dependencies
-------------------

- numpy
- pandas
- (for SOAP-PP) modeller
- (for SOAP-PP) mdt

Installing
==========

1. Set up paths in PATHS.ini

2. (To use SOAP-PP): Install python dependencies with Anaconda:


```bash
conda config --add channels salilab
conda install modeller
conda install -c salilab mdt
```

Running
=======

See the test for an example of how to run using the "Final generation" strategy:

```bash
cd test/
bash run_test.sh
```

To use the "Lowest RMSD" strategy, determine which model in the final generation has the lowest RMSD and create `lowest.ga.out` with the header (first 8 lines including blank line) but only one model line (e.g. "0,1,7416;0,2,19    -41.273 154 -36508.2"). Then run `./path_lzerd.py -p sample -d . -g lowest.ga.out -o lowest.csv`

To use the "Consensus" strategy, run Multi-LZerD 1 generation at a time using the "--resume" flag, e.g.:

```bash
multilzerd --pdbid sample --chains A,B,C --generations 1000 -o sample.1000
multilzerd --pdbid sample --chains A,B,C --resume sample.1000.ga.out --generations 1 -o sample.1001
multilzerd --pdbid sample --chains A,B,C --resume sample.1001.ga.out --generations 1 -o sample.1002
```

Then create `consensus.ga.out` with the header from one file and the model lines from all files, and run `./path_lzerd.py -p sample -d . -g consensus.ga.out -o consensus.csv`

Adding additional scores
========================

1. Put any required paths into PATHS.ini

2. Edit SCORES.py (in the following text, `SCORENAME` should be replaced with the name of the score):
- Add entry `SCORENAME="x"` to dict `possible_scores` where x is any required entries in PATHS.ini
- Create class MyScoreObject with
    - `__init__` method that runs score and accepts arguments:
        - any PATHS.ini entries in `possible_scores`
        - input (list of files)
        - directory (directory containing files)
        - pattern (glob pattern in directory, e.g. `*.pdb`)
        - wd (directory for output file)
        - output_file (filename to write scores)
    - `load` method that loads score into pandas DataFrame with pdbfile in column 'model' and score in column 'SCORENAME'
- Add entry `SCORENAME=MyScoreObject` to dict `scorers`
- If score is not ascending (i.e. lower is better), add entry `SCORENAME=dict(fmt="{0}-{1}_SCORENAME.txt", ascending=False)` to dict `score_files`
